[Interface]
PrivateKey = {{ private_key }}
Address = {{ ip }}/{{ prefix }}
DNS = {{ dns }}

[Peer]
PublicKey = {{ server_pub }}
Endpoint = {{ server_ip }}:{{ port }}
AllowedIPs = 0.0.0.0/0, ::/0
PersistentKeepalive = {{ keepalive }}
